module Natter
  # Public: An entity is an attribute of an intent.
  class Entity
    attr_accessor :name, :type

    # Public: Constructor.
    #
    # name  - Must be unique within an individual intent.
    # type  - One of the pre-defined EntityType constants (default: 'generic')
    # value - Will never be nil when generated by the parser but may be nil
    #         for some rule definitions (default: nil).
    def initialize(name, type = EntityType::GENERIC, value = nil)
      @name = name
      @type = type
      @value = value
    end

    # Public: Set this entity's value.
    #
    # value - The new value.
    def value=(v)
      @value = v
    end

    # Public: Returns the value of this entity.
    # If @type is `generic` then we just return @value, otherwise we will need
    # to verify/compute the value to return.
    #
    # Returns object or nil (if invalid @value)
    def value
      case @type
      when EntityType::TIME
        return Chronic.parse(@value) # returns Time or nil
      else
        return @value
      end
    end
  end

  # Public: Exists only to expose its constants which are used to define
  # Entity types.
  class EntityType
    GENERIC = 'generic'
    TIME = 'time'
  end
end
