module Natter
  # Public: Represents an intent derived by the parser from an utterance.
  class Intent
    # The string name of this intent.
    attr_accessor :name
    # The name of the skill that this intent belongs to.
    attr_accessor :skill
    # How confident the parser is that this is the correct intent (from 0.0 - 1.0).
    attr_accessor :confidence
    # An array of entities discovered in the utterance. May be empty.
    attr_accessor :entities

    # Public: Constructor.
    # 
    # name       - The String name of this intent. Does not have to be unique.
    # skill      - The name of the skill that this intent belongs to. Defaults 
    #              to the global namespace/skill (default: '')
    # confidence - Float value between 0-1 reflects how confident the parser is 
    #              that this intent is correct (default: 1.0).
    # entities   - An array of Natter::Entity objects (default: nil).
    def initialize(name, skill = '', confidence = 1.0, entities = nil)
      @name = name
      @skill = skill
      @confidence = confidence
      @entities = entities || []
    end
  end
end